@@ -14,8 +14,7 @@ import json
 import uuid
 from datetime import date, datetime, time
 
-import requests
-from flask import Blueprint, Flask, abort, jsonify
+from flask import Blueprint, Flask, abort
 from flask.views import MethodView
 from werkzeug.utils import find_modules
 
@@ -106,6 +105,7 @@ class BaseModel(TodictMixin):
 
 class JSONEncoder(json.JSONEncoder):
     def default(self, o):
+        print(o)
         # See "Date Time String Format" in the ECMA-262 specification.
         if isinstance(o, set):
             return list(o)
@@ -130,24 +130,6 @@ class CustomFlask(Flask):
 
     json_encoder = JSONEncoder
 
-    def make_response(self, rv):
-        if isinstance(rv, (dict, list, tuple)):
-            rv = jsonify(rv)
-        elif isinstance(rv, requests.Response):
-            headers = rv.headers
-            for key in [
-                "Server",
-                "Connection",
-                "Content-Length",
-                "Set-Cookie",
-                "Content-Encoding",
-                "Transfer-Encoding",
-            ]:
-                headers.pop(key, None)
-            rv = rv.content, rv.status_code, headers.items()
-
-        return super().make_response(rv)
-
 
 # Views Mixin
 class PaginationMixin:
